@@ -82,6 +82,11 @@ static bool wait_for_another_argument(std::string& argument)
         Last_Argument = "--policyreferencefile=";
         return true;
     }
+    else if (argument=="-pv")
+    {
+        Last_Argument = "--policyverbosity=";
+        return true;
+    }
     else if (argument=="-up")
     {
         Last_Argument = "--useplugin=";
@@ -107,6 +112,47 @@ static bool wait_for_another_argument(std::string& argument)
         Last_Argument = "--watchfolder-user=";
         return true;
     }
+    else if (argument=="-o")
+    {
+        Last_Argument = "--output=";
+        return true;
+    }
+    else if (argument=="-ot")
+    {
+        Last_Argument = "--output-text=";
+        return true;
+    }
+    else if (argument=="-ox")
+    {
+        Last_Argument = "--output-xml=";
+        return true;
+    }
+    else if (argument=="-oa")
+    {
+        argument = "--output-maxml=";
+        return true;
+    }
+    else if (argument=="-oj")
+    {
+        Last_Argument = "--output-jstree=";
+        return true;
+    }
+    else if (argument=="-oh")
+    {
+        Last_Argument = "--output-html=";
+        return true;
+    }
+    else if (argument=="-oc")
+    {
+        Last_Argument = "--output-csv=";
+        return true;
+    }
+    else if (argument=="-os")
+    {
+        Last_Argument = "--output-simple=";
+        return true;
+    }
+
     return false;
 }
 
@@ -214,6 +260,7 @@ int Parse(MediaConch::CLI* cli, std::string& argument)
     OPTION("--report",                                      Report)
     OPTION("--format",                                      Format)
     OPTION("--policyreferencefile",                         PolicyReferenceFile)
+    OPTION("--policyverbosity",                             PolicyVerbosity)
     OPTION("--policy",                                      PolicyOption)
     OPTION("--display",                                     Display)
     OPTION("--logfile",                                     LogFile)
@@ -222,6 +269,7 @@ int Parse(MediaConch::CLI* cli, std::string& argument)
     OPTION("--implementationverbosity",                     ImplementationVerbosity)
     OPTION("--compression",                                 Compression)
     OPTION("--force",                                       Force)
+    OPTION("--full",                                        Full)
     OPTION("--nomilanalyze",                                NoMilAnalyze)
     OPTION("--async",                                       Asynchronous)
     OPTION("--pluginslist",                                 PluginsList)
@@ -237,6 +285,15 @@ int Parse(MediaConch::CLI* cli, std::string& argument)
     OPTION("--watchfolder",                                 WatchFolder)
     OPTION("--user",                                        User)
     OPTION("--list",                                        List)
+    OPTION("--output",                                      Output)
+    OPTION("--output-text",                                 Output)
+    OPTION("--output-xml",                                  Output)
+    OPTION("--output-maxml",                                Output)
+    OPTION("--output-jstree",                               Output)
+    OPTION("--output-html",                                 Output)
+    OPTION("--output-csv",                                  Output)
+    OPTION("--output-simple",                               Output)
+
     //Default
     OPTION("--",                                            Default)
     else
@@ -324,8 +381,23 @@ CL_OPTION(PolicyOption)
 
     std::string file;
     file.assign(argument, egal_pos + 1, std::string::npos);
-    cli->add_policy(file);
+    return cli->add_policy(file);
+}
 
+//---------------------------------------------------------------------------
+CL_OPTION(PolicyVerbosity)
+{
+    //Form : --PolicyVerbosity=Value
+    size_t egal_pos = argument.find('=');
+    if (egal_pos == std::string::npos)
+    {
+        Help_Usage();
+        return CLI_RETURN_ERROR;
+    }
+
+    std::string verbosity;
+    verbosity.assign(argument, egal_pos + 1 , std::string::npos);
+    cli->set_policy_verbosity(verbosity);
     return CLI_RETURN_NONE;
 }
 
@@ -450,6 +522,14 @@ CL_OPTION(Force)
     return CLI_RETURN_NONE;
 }
 
+//---------------------------------------------------------------------------
+CL_OPTION(Full)
+{
+    (void)argument;
+    cli->set_full_report(true);
+    return CLI_RETURN_NONE;
+}
+
 //---------------------------------------------------------------------------
 CL_OPTION(NoMilAnalyze)
 {
@@ -681,6 +761,30 @@ CL_OPTION(List)
     return CLI_RETURN_NONE;
 }
 
+//---------------------------------------------------------------------------
+CL_OPTION(Output)
+{
+    //Form : --output<-format>=file, -o file
+    size_t egal_pos = argument.find('=');
+    if (egal_pos == std::string::npos)
+    {
+        Help();
+        return CLI_RETURN_ERROR;
+    }
+
+    std::string filename;
+    filename.assign(argument, egal_pos + 1 , std::string::npos);
+
+    std::string format;
+    size_t minus_pos = argument.rfind('-', egal_pos);
+    if (minus_pos != std::string::npos && minus_pos > 1)
+        format.assign(argument, minus_pos + 1, egal_pos - minus_pos - 1);
+
+    cli->add_output(format, filename);
+
+    return CLI_RETURN_NONE;
+}
+
 //---------------------------------------------------------------------------
 CL_OPTION(Default)
 {
