@@ -138,15 +138,19 @@ public:
     {
         std::string           report;
         bool                  has_valid;
+        bool                  has_info;
+        bool                  has_warning;
         bool                  valid;
-        Checker_ReportRes() : has_valid(false), valid(true) {}
+        Checker_ReportRes() : has_valid(false), has_info(false), has_warning(false), valid(true) {}
     };
 
     struct Checker_ValidateRes
     {
         long                    id;
         bool                    valid;
-        Checker_ValidateRes() : valid(true) {}
+        bool                    has_info;
+        bool                    has_warning;
+        Checker_ValidateRes() : valid(true), has_info(false), has_warning(false) {}
     };
 
     struct Checker_FileInfo
@@ -171,14 +175,15 @@ public:
 
     struct XSLT_Policy_Rule
     {
-        XSLT_Policy_Rule() : id(-1), occurrence(-1) {}
+        XSLT_Policy_Rule() : id(-1) {}
 
         int          id;
         std::string  name;
         std::string  tracktype;
         std::string  field;
         std::string  scope;
-        int          occurrence;
+        std::string  level;
+        std::string  occurrence;
         std::string  ope;
         std::string  value;
         std::string  to_str() const;
@@ -187,7 +192,7 @@ public:
     struct Policy_Policy
     {
         Policy_Policy() : id(-1), parent_id(-1), is_system(false) {}
-        Policy_Policy(const Policy_Policy* p) : id(p->id), parent_id(p->parent_id), is_system(p->is_system), is_public(p->is_public), kind(p->kind), type(p->type), name(p->name), description(p->description), tags(p->tags), license(p->license), children(p->children) {}
+        Policy_Policy(const Policy_Policy* p) : id(p->id), parent_id(p->parent_id), is_system(p->is_system), is_public(p->is_public), kind(p->kind), type(p->type), name(p->name), description(p->description), tags(p->tags), level(p->level), license(p->license), children(p->children) {}
         int                                       id;
         int                                       parent_id;
         bool                                      is_system;
@@ -197,6 +202,7 @@ public:
         std::string                               name;
         std::string                               description;
         std::vector<std::string>                  tags;
+        std::string                               level;
         std::string                               license;
         std::vector<std::pair<int, XSLT_Child> >  children;
         std::string                               to_str() const;
@@ -338,7 +344,7 @@ public:
     int                          policy_duplicate(int user, int id, int dst_policy_id, int *dst_user, bool must_be_public, std::string& err);
     int                          policy_move(int user, int id, int dst_policy_id, std::string& err);
     int                          policy_change_info(int user, int id, const std::string& name, const std::string& description,
-                                                    const std::vector<std::string>& tags, const std::string& license, std::string& err);
+                                                    const std::vector<std::string>& tags, const std::string& level, const std::string& license, std::string& err);
     int                          policy_change_type(int user, int id, const std::string& type, std::string& err);
     int                          policy_change_is_public(int user, int id, bool is_public, std::string& err);
     int                          xslt_policy_create(int user, std::string& err, const std::string& type="and", int parent_id=-1);
