@@ -148,12 +148,14 @@ int Reports::checker_validate(int user, MediaConchLib::report report, const std:
                                      policies_contents.size() ? &policies_contents : NULL) < 0)
                 continue;
             res->valid = tmp_res.has_valid ? tmp_res.valid : true;
+            res->has_info = tmp_res.has_info;
+            res->has_warning = tmp_res.has_warning;
         }
         else if (report == MediaConchLib::report_MediaConch)
         {
             //XXX
             std::string report;
-            if (get_implementation_report(user, files[i], options, report, res->valid, err) < 0)
+            if (get_implementation_report(user, files[i], options, report, res->valid, res->has_info, res->has_warning, err) < 0)
                 return -1;
         }
         else if (report == MediaConchLib::report_MediaVeraPdf)
@@ -266,7 +268,9 @@ int Reports::get_reports_output(int user, const std::vector<long>& files,
             std::string tmp;
             std::string err;
             bool is_valid = false;
-            if (get_implementation_reports(user, files, options, tmp, is_valid, err) < 0)
+            bool has_info = false;
+            bool has_warning = false;
+            if (get_implementation_reports(user, files, options, tmp, is_valid, has_info, has_warning, err) < 0)
                 tmp = std::string();
 
             if (f == MediaConchLib::format_Html)
@@ -284,6 +288,13 @@ int Reports::get_reports_output(int user, const std::vector<long>& files,
 
             if (!result->has_valid)
                 result->has_valid = true;
+
+            if (!result->has_info)
+                result->has_info = has_info;
+
+            if (!result->has_warning)
+                result->has_warning = has_warning;
+
             if (!is_valid)
                 result->valid = false;
 
@@ -464,10 +475,12 @@ int Reports::get_reports_output_JStree(int user, const std::vector<long>& files,
 //---------------------------------------------------------------------------
 int Reports::get_implementation_reports(int user, const std::vector<long>& files,
                                         const std::map<std::string, std::string>& options,
-                                        std::string& report, bool& valid, std::string& err)
+                                        std::string& report, bool& valid, bool& has_info, bool& has_warning, std::string& err)
 {
     bool AcceptsHttps = core->accepts_https();
     valid = true;
+    has_info = false;
+    has_warning = false;
 
     std::stringstream verbo;
     std::map<std::string, std::string>::const_iterator it = options.find("verbosity");
@@ -493,7 +506,9 @@ int Reports::get_implementation_reports(int user, const std::vector<long>& files
         report += "  <media ref=\"" + file + "\">";
         std::string implem;
         bool v = false;
-        if (get_implementation_report(user, files[i], options, implem, v, err) < 0)
+        bool info = false;
+        bool warn = false;
+        if (get_implementation_report(user, files[i], options, implem, v, info, warn, err) < 0)
             implem = std::string();
         else
             get_content_of_media_in_xml(implem);
@@ -502,6 +517,9 @@ int Reports::get_implementation_reports(int user, const std::vector<long>& files
 
         if (!v)
             valid = false;
+
+        has_info |= info;
+        has_warning |= warn;
     }
 
     report += "</MediaConch>\n";
@@ -511,10 +529,12 @@ int Reports::get_implementation_reports(int user, const std::vector<long>& files
 
 //---------------------------------------------------------------------------
 int Reports::get_implementation_report(int user, long file, const std::map<std::string, std::string>& options,
-                                       std::string& report, bool& valid, std::string& err)
+                                       std::string& report, bool& valid, bool& has_info, bool& has_warning, std::string& err)
 {
     std::string options_str = Core::serialize_string_from_options_map(options);
     valid = true;
+    has_info = false;
+    has_warning = false;
     std::string tmp_report;
 
     bool registered = false;
@@ -542,7 +562,10 @@ int Reports::get_implementation_report(int user, long file, const std::map<std::
         return -1;
 
     if (valid)
+    {
         valid = implementation_is_valid(tmp_report);
+        implementation_has_info_or_warning(tmp_report, has_info, has_warning);
+    }
     report += tmp_report;
 
     return 0;
@@ -844,7 +867,9 @@ int Reports::create_report_ma_xml(int user, const std::vector<long>& files,
         {
             std::string implem;
             bool valid;
-            if (get_implementation_report(user, files[i], options, implem, valid, err) < 0)
+            bool info;
+            bool warning;
+            if (get_implementation_report(user, files[i], options, implem, valid, info, warning, err) < 0)
                 implem = std::string();
             else
                 get_content_of_media_in_xml(implem);
@@ -981,6 +1006,33 @@ bool Reports::implementation_is_valid(const std::string& report)
     return true;
 }
 
+//---------------------------------------------------------------------------
+bool Reports::implementation_has_info_or_warning(const std::string& report, bool& has_info, bool& has_warning)
+{
+    has_info=false;
+    has_warning=false;
+
+    size_t pos=0;
+    std::string search(" outcome=\"");
+    while ((pos = report.find(search, pos)) != std::string::npos)
+    {
+        if (pos + search.size() + 4 < report.size())
+        {
+            if (report[pos + search.size()] == 'i' && report[pos + search.size() + 1] == 'n' && report[pos + search.size() + 2] == 'f' && report[pos + search.size() + 3] == 'o')
+                has_info = true;
+            else if (report[pos + search.size()] == 'w' && report[pos + search.size() + 1] == 'a' && report[pos + search.size() + 2] == 'r' && report[pos + search.size() + 3] == 'n')
+                has_warning = true;
+
+            if (has_info && has_warning)
+                break;
+        }
+
+        pos += search.size();
+    }
+
+    return has_info || has_warning;
+}
+
 //---------------------------------------------------------------------------
 bool Reports::policy_is_valid(const std::string& report)
 {
@@ -1004,6 +1056,33 @@ bool Reports::policy_is_valid(const std::string& report)
     return true;
 }
 
+//---------------------------------------------------------------------------
+bool Reports::policy_has_info_or_warning(const std::string& report, bool& has_info, bool& has_warning)
+{
+    has_info=false;
+    has_warning=false;
+
+    size_t pos=0;
+    std::string search(" outcome=\"");
+    while ((pos = report.find(search, pos)) != std::string::npos)
+    {
+        if (pos + search.size() + 4 < report.size())
+        {
+            if (report[pos + search.size()] == 'i' && report[pos + search.size() + 1] == 'n' && report[pos + search.size() + 2] == 'f' && report[pos + search.size() + 3] == 'o')
+                has_info = true;
+            else if (report[pos + search.size()] == 'w' && report[pos + search.size() + 1] == 'a' && report[pos + search.size() + 2] == 'r' && report[pos + search.size() + 3] == 'n')
+                has_warning = true;
+
+            if (has_info && has_warning)
+                break;
+        }
+
+        pos += search.size();
+    }
+
+    return has_info || has_warning;
+}
+
 //---------------------------------------------------------------------------
 bool Reports::verapdf_report_is_valid(const std::string& report)
 {
@@ -1069,9 +1148,9 @@ int Reports::check_policies(int user, const std::vector<long>& files,
 
     std::stringstream Out;
     result->has_valid = true;
-    if (check_policies_xmls(user, files, options, xml_policies, Out, result->valid, err) < 0)
+    if (check_policies_xmls(user, files, options, xml_policies, Out, result->valid, result->has_info, result->has_warning, err) < 0)
     {
-        if (check_policies_xslts(user, files, options, xslt_policies, Out, result->valid, err) < 0)
+        if (check_policies_xslts(user, files, options, xslt_policies, Out, result->valid, result->has_info, result->has_warning, err) < 0)
             return -1;
     }
 
@@ -1083,7 +1162,8 @@ int Reports::check_policies(int user, const std::vector<long>& files,
 int Reports::check_policies_xmls(int user, const std::vector<long>& files,
                                    const std::map<std::string, std::string>& options,
                                    const std::vector<std::string>& policies,
-                                   std::stringstream& Out, bool& valid, std::string& err)
+                                   std::stringstream& Out, bool& valid,
+                                   bool& has_info, bool& has_warning, std::string& err)
 {
     std::map<std::string,std::string> opts=options;
     valid = true;
@@ -1096,10 +1176,11 @@ int Reports::check_policies_xmls(int user, const std::vector<long>& files,
     for (size_t i = 0; i < policies.size(); ++i)
         checker.add_policy(policies[i]);
 
+    if (!checker.is_policy_supported())
+        return -1;
+
     if (checker.full_parse())
         opts["full_report"] = "\"1\"";
-    else
-        return -1;
 
     std::string report;
     if (create_report_ma_xml(user, files, opts, report, get_bitset_with_mi_mmt(), err) < 0)
@@ -1119,6 +1200,7 @@ int Reports::check_policies_xmls(int user, const std::vector<long>& files,
         Out << tmp;
         if (!policy_is_valid(tmp))
             valid = false;
+        policy_has_info_or_warning(tmp, has_info, has_warning);
     }
 
     return 0;
@@ -1128,7 +1210,8 @@ int Reports::check_policies_xmls(int user, const std::vector<long>& files,
 int Reports::check_policies_xslts(int user, const std::vector<long>& files,
                                    const std::map<std::string, std::string>& options,
                                    const std::vector<std::string>& policies,
-                                   std::stringstream& Out, bool& valid, std::string& err)
+                                   std::stringstream& Out, bool& valid,
+                                   bool& has_info, bool& has_warning, std::string& err)
 {
     valid = true;
     for (size_t i = 0; i < policies.size(); ++i)
@@ -1145,6 +1228,8 @@ int Reports::check_policies_xslts(int user, const std::vector<long>& files,
             Out << tmp;
             if (!policy_is_valid(tmp))
                 valid = false;
+
+            policy_has_info_or_warning(tmp, has_info, has_warning);
         }
     }
     return 0;
