@@ -68,7 +68,6 @@ size_t XsltPolicyRule::rule_id = 0;
 XsltPolicyRule::XsltPolicyRule() : XsltPolicyNode()
 {
     kind = XSLT_POLICY_RULE;
-    this->occurrence = -1;
 }
 
 //---------------------------------------------------------------------------
@@ -87,6 +86,7 @@ XsltPolicyRule::XsltPolicyRule(const XsltPolicyRule* r) : XsltPolicyNode(r)
     this->track_type = r->track_type;
     this->field      = r->field;
     this->scope      = r->scope;
+    this->level      = r->level;
     this->occurrence = r->occurrence;
     this->value      = r->value;
 }
@@ -102,6 +102,7 @@ XsltPolicyRule::XsltPolicyRule(const XsltPolicyRule& r) : XsltPolicyNode(r)
     this->track_type = r.track_type;
     this->field      = r.field;
     this->scope      = r.scope;
+    this->level      = r.level;
     this->occurrence = r.occurrence;
     this->value      = r.value;
 }
@@ -114,6 +115,7 @@ int XsltPolicyRule::edit_policy_rule(const XsltPolicyRule* rule, std::string&)
     this->track_type = rule->track_type;
     this->field      = rule->field;
     this->scope      = rule->scope;
+    this->level      = rule->level;
     this->occurrence = rule->occurrence;
     this->value      = rule->value;
 
@@ -379,6 +381,13 @@ int XsltPolicy::parse_policy_policy(xmlNodePtr node, bool is_root, XsltPolicy* c
         xmlFree(is_public);
     }
 
+    xmlChar *level = xmlGetNoNsProp(node, (const unsigned char*)"level");
+    if (level)
+    {
+        p->level = std::string((const char*)level);
+        xmlFree(level);
+    }
+
     xmlChar *license = xmlGetNoNsProp(node, (const unsigned char*)"license");
     if (license && is_root)
     {
@@ -443,6 +452,10 @@ int XsltPolicy::parse_policy_rule(xmlNodePtr node, bool is_root, XsltPolicy* cur
     {
         r->field = std::string((const char*)field);
         xmlFree(field);
+
+        // Handle old typo in MediaInfoLib
+        if (r->field == "TimeCode_Striped")
+            r->field = "TimeCode_Stripped";
     }
 
     //Get scope
@@ -453,19 +466,19 @@ int XsltPolicy::parse_policy_rule(xmlNodePtr node, bool is_root, XsltPolicy* cur
         xmlFree(scope);
     }
 
+    //Get level
+    xmlChar *level = xmlGetNoNsProp(node, (const unsigned char*)"level");
+    if (level)
+    {
+        r->level = std::string((const char*)level);
+        xmlFree(level);
+    }
+
     //Get occurrence
     xmlChar *occurrence = xmlGetNoNsProp(node, (const unsigned char*)"occurrence");
     if (occurrence)
     {
-        std::string occ((const char*)occurrence);
-
-        if (occ == "*")
-            r->occurrence = -1;
-        else
-        {
-            char *end;
-            r->occurrence = strtol(occ.c_str(), &end, 10);
-        }
+        r->occurrence = std::string((const char*)occurrence);
         xmlFree(occurrence);
     }
 
@@ -543,6 +556,10 @@ int XsltPolicy::create_node_policy_child(xmlNodePtr& node, XsltPolicy *current)
         }
     }
 
+    //level
+    if (current->level.size())
+        xmlNewProp(node, (const xmlChar *)"level", (const xmlChar *)current->level.c_str());
+
     //isPublic
     if (current->keep_public && current->is_public)
         xmlNewProp(node, (const xmlChar *)"isPublic", (const xmlChar *)"true");
@@ -583,25 +600,21 @@ int XsltPolicy::create_node_rule_child(xmlNodePtr& node, XsltPolicyRule *current
         xmlNewProp(node, (const xmlChar *)"tracktype", (const xmlChar *)current->track_type.c_str());
 
     //occurrence
-    std::stringstream ss;
-    std::string occurrence;
-    if (current->occurrence >= 0)
-    {
-        ss << current->occurrence;
-        occurrence = ss.str();
-    }
-    else
-        occurrence = "*";
-    xmlNewProp(node, (const xmlChar *)"occurrence", (const xmlChar *)occurrence.c_str());
+    if (current->occurrence.size())
+        xmlNewProp(node, (const xmlChar *)"occurrence", (const xmlChar *)current->occurrence.c_str());
 
     //operator
     if (current->ope.size())
         xmlNewProp(node, (const xmlChar *)"operator", (const xmlChar *)current->ope.c_str());
 
-    //operator
+    //scope
     if (current->scope.size())
         xmlNewProp(node, (const xmlChar *)"scope", (const xmlChar *)current->scope.c_str());
 
+    //level
+    if (current->level.size())
+        xmlNewProp(node, (const xmlChar *)"level", (const xmlChar *)current->level.c_str());
+
     //value
     if (current->value.size())
         xmlNodeSetContent(node, (const xmlChar*)current->value.c_str());
@@ -703,7 +716,10 @@ int XsltPolicy::create_rule_from_media_track_child(xmlNodePtr node, const std::s
          || name == "BitRate"
          || name == "Delay"
          || name == "Count"
-         || name == "CodecID_Url")
+         || name == "CodecID_Url"
+         || name == "ConformanceErrors"
+         || name == "ConformanceWarnings"
+         || name == "ConformanceInfos")
             continue;
 
         if(xmlChildElementCount(child))
@@ -726,7 +742,7 @@ int XsltPolicy::create_rule_from_media_track_child(xmlNodePtr node, const std::s
         rule->track_type = type;
         rule->field = prefix + (const char*)child->name;
         rule->ope = "=";
-        rule->occurrence = -1;
+        rule->occurrence = "*";
         xmlChar *content = xmlNodeGetContent(child);
         if (content)
             rule->value = (const char*)content;
