@@ -197,4 +197,37 @@ void DatabaseUi::get_sql_query_for_update_ui_table_v11(std::string& q)
     q = create.str();
 }
 
+//---------------------------------------------------------------------------
+void DatabaseUi::get_sql_query_for_update_ui_table_v12(std::string& q)
+{
+    std::stringstream create;
+    create << "ALTER TABLE UI"; // Table name
+    create << " ADD POLICY_HAS_INFO BOOL DEFAULT FALSE;";
+    create << "ALTER TABLE UI"; // Table name
+    create << " ADD POLICY_HAS_WARNING BOOL DEFAULT FALSE;";
+    q = create.str();
+}
+
+//---------------------------------------------------------------------------
+void DatabaseUi::get_sql_query_for_update_ui_settings_table_v13(std::string& q)
+{
+    std::stringstream create;
+    create << "ALTER TABLE UI_SETTINGS"; // Table name
+    create << " ADD DEFAULT_PARSESPEED TEXT NOT NULL DEFAULT 'last';";
+    create << "ALTER TABLE UI_SETTINGS"; // Table name
+    create << " ADD LAST_PARSESPEED TEXT DEFAULT NULL;";
+    q = create.str();
+}
+
+//---------------------------------------------------------------------------
+void DatabaseUi::get_sql_query_for_update_ui_table_v14(std::string& q)
+{
+    std::stringstream create;
+    create << "ALTER TABLE UI"; // Table name
+    create << " ADD IMPLEMENTATION_HAS_INFO BOOL DEFAULT FALSE;";
+    create << "ALTER TABLE UI"; // Table name
+    create << " ADD IMPLEMENTATION_HAS_WARNING BOOL DEFAULT FALSE;";
+    q = create.str();
+}
+
 }
