@@ -150,6 +150,18 @@ int NoDatabaseUi::ui_settings_get_default_verbosity(int&, int)
     return 0;
 }
 
+//---------------------------------------------------------------------------
+int NoDatabaseUi::ui_settings_save_default_parsespeed(const std::string&, int)
+{
+    return 0;
+}
+
+//---------------------------------------------------------------------------
+int NoDatabaseUi::ui_settings_get_default_parsespeed(std::string&, int)
+{
+    return 0;
+}
+
 //---------------------------------------------------------------------------
 int NoDatabaseUi::ui_settings_save_last_policy(const std::string&, int)
 {
@@ -186,6 +198,18 @@ int NoDatabaseUi::ui_settings_get_last_verbosity(int&, int)
     return 0;
 }
 
+//---------------------------------------------------------------------------
+int NoDatabaseUi::ui_settings_save_last_parsespeed(const std::string&, int)
+{
+    return 0;
+}
+
+//---------------------------------------------------------------------------
+int NoDatabaseUi::ui_settings_get_last_parsespeed(std::string&, int)
+{
+    return 0;
+}
+
 //---------------------------------------------------------------------------
 int NoDatabaseUi::ui_settings_save_default_load_files_path(const std::string&, int)
 {
