@@ -246,6 +246,12 @@ int MainWindow::add_file_to_list(const QString& file, const QString& path,
     uisettings.change_last_display(displays_list[display_i].toUtf8().data());
     uisettings.change_last_verbosity(verbosity_i);
 
+    int parsespeed_idx = options.lastIndexOf("file_parsespeed");
+    if (parsespeed_idx != -1 && parsespeed_idx < options.size())
+        uisettings.change_last_parsespeed(options[parsespeed_idx + 1].toStdString());
+    else
+        uisettings.change_last_parsespeed("");
+
     std::string full_path = filepath;
 #ifdef WINDOWS
     if (full_path.length() && full_path[full_path.size() - 1] != '/' && full_path[full_path.size() - 1] != '\\')
@@ -1010,11 +1016,11 @@ int MainWindow::policy_move(int id, int dst_policy_id, QString& err)
 }
 
 //---------------------------------------------------------------------------
-int MainWindow::policy_change_info(int id, const std::string& name, const std::string& description,
-                                   const std::vector<std::string>& tags, const std::string& license, QString& err)
+int MainWindow::policy_change_info(int id, const std::string& name, const std::string& description, const std::vector<std::string>& tags,
+                                   const std::string& level, const std::string& license, QString& err)
 {
     std::string error;
-    int ret = MCL.policy_change_info(user, id, name, description, tags, license, error);
+    int ret = MCL.policy_change_info(user, id, name, description, tags, level, license, error);
     if (ret < 0)
         err = QString().fromUtf8(error.c_str(), error.size());
     return ret;
@@ -1262,6 +1268,18 @@ int MainWindow::select_correct_verbosity()
     return verbosity;
 }
 
+//---------------------------------------------------------------------------
+std::string MainWindow::select_correct_parsespeed()
+{
+    // Parsespeed
+    std::string parsespeed = uisettings.get_default_parsespeed();
+    if (parsespeed == "last")
+        parsespeed = uisettings.get_last_parsespeed();
+    if (parsespeed.empty())
+        parsespeed = "0.5";
+    return parsespeed;
+}
+
 //---------------------------------------------------------------------------
 std::string MainWindow::select_correct_save_report_path()
 {
