@@ -5,10 +5,10 @@ var checkerAjax = (function() {
         var options = [];
         if (formType === 'file')
         {
-            if ($('#checkerUpload_parseSpeed').is(':checked'))
+            if ($('#checkerUpload_parsespeed_selector').val() !== '0.5')
             {
                 options.push("file_parsespeed");
-                options.push("1");
+                options.push($('#checkerUpload_parsespeed_selector').val());
             }
 
             res = webpage.on_file_upload_selected($('.tab-content .active .policyList').val(),
@@ -19,12 +19,11 @@ var checkerAjax = (function() {
         }
         else if (formType === 'url')
         {
-            if ($('#checkerOnline_parseSpeed').is(':checked'))
+            if ($('#checkerOnline_parsespeed_selector').val() !== '0.5')
             {
                 options.push("file_parsespeed");
-                options.push("1");
+                options.push($('#checkerOnline_parsespeed_selector').val());
             }
-
             res = webpage.on_file_online_selected($('#checkerOnline_file').val(),
                                                   $('.tab-content .active .policyList').val(),
                                                   $('.tab-content .active .displayList').val(),
@@ -33,10 +32,10 @@ var checkerAjax = (function() {
         }
         else if (formType === 'repository')
         {
-            if ($('#checkerRepository_parseSpeed').is(':checked'))
+            if ($('#checkerRepository_parsespeed_selector').val() !== '0.5')
             {
                 options.push("file_parsespeed");
-                options.push("1");
+                options.push($('#checkerRepository_parsespeed_selector').val());
             }
 
             res = webpage.on_file_repository_selected($('.tab-content .active .policyList').val(),
