@@ -118,6 +118,10 @@ var policyTreeAjax = (function() {
         if (type === null)
             type = "";
 
+        var level = $("#xslPolicyInfo_policyLevel").val();
+        if (level === null)
+            level = "";
+
         var license = $("#xslPolicyInfo_policyLicense").val();
         if (license === null || license === "Other")
             license = "";
@@ -126,7 +130,7 @@ var policyTreeAjax = (function() {
         if (visibility === null)
             visibility = "";
 
-        webpage.policy_edit(policyNode.data.policyId, name, description, tags, license, type, visibility, function(res){
+        webpage.policy_edit(policyNode.data.policyId, name, description, tags, license, type, level, visibility, function(res){
             data = JSON.parse(res);
             if (!data.error)
                 policyTree.policyEdit(data.policyTree, policyNode);
@@ -208,7 +212,7 @@ var policyTreeAjax = (function() {
          * @param int policyId policy ID of the policy that will contain the rule
          *
          * @return json
-         * {"rule":{"tracktype":TRACKTYPE, "field":FIELD, "id":RULE_ID, "name":NAME, "value":VALUE, "occurrence":OCCURENCE,  "ope":OPERATOR}}
+         * {"rule":{"tracktype":TRACKTYPE, "field":FIELD, "level" LEVEL, "id":RULE_ID, "name":NAME, "value":VALUE, "occurrence":OCCURENCE,  "ope":OPERATOR}}
          */
         webpage.xslt_policy_rule_create(policyNode.data.policyId, function(res){
             data = JSON.parse(res);
@@ -226,14 +230,15 @@ var policyTreeAjax = (function() {
          * @param int policyId policy ID of the policy that contain the rule
          *
          * @return json
-         * {"rule":{"tracktype":TRACKTYPE, "field":FIELD, "id":RULE_ID, "name":NAME, "value":VALUE, "occurrence":OCCURENCE, "ope":OPERATOR}}
+         * {"rule":{"tracktype":TRACKTYPE, "field":FIELD, "level" LEVEL, "id":RULE_ID, "name":NAME, "value":VALUE, "occurrence":OCCURENCE, "ope":OPERATOR}}
          */
 
         var scope = "";
+        var level = "";
         var name = "";
         var tracktype = "";
         var field = "";
-        var occurrence = -1;
+        var occurrence = "";
         var ope = "";
         var value = "";
 
@@ -250,6 +255,10 @@ var policyTreeAjax = (function() {
             if (field === null)
                 field = "";
 
+            level = $("#xslPolicyRuleMt_level").val();
+            if (level === null)
+                level = "";
+
             ope = $("#xslPolicyRuleMt_validator").val();
             if (ope === null)
                 ope = "";
@@ -272,9 +281,13 @@ var policyTreeAjax = (function() {
             if (field === null)
                 field = "";
 
+            level = $("#xslPolicyRule_level").val();
+            if (level === null)
+                level = "";
+
             occurrence = $("#xslPolicyRule_occurrence").val();
-            if (occurrence === null || occurrence === "*" || occurrence === "")
-                occurrence = -1;
+            if (occurrence === null)
+                occurrence = "";
 
             ope = $("#xslPolicyRule_validator").val();
             if (ope === null)
@@ -285,7 +298,7 @@ var policyTreeAjax = (function() {
                 value = "";
         }
 
-        webpage.xslt_policy_rule_edit(ruleNode.data.ruleId, policyId, name, tracktype, field, occurrence, ope, value, scope, function(res){
+        webpage.xslt_policy_rule_edit(ruleNode.data.ruleId, policyId, name, tracktype, field, occurrence, ope, value, scope, level, function(res){
             data = JSON.parse(res);
             if (!data.error)
                 policyTree.ruleEdit(data.rule, ruleNode);
@@ -320,7 +333,7 @@ var policyTreeAjax = (function() {
          * @param int dstPolicyId policy ID of the destination policy
          *
          * @return json
-         * {"rule":{"tracktype":TRACKTYPE, "field":FIELD, "id":RULE_ID, "name":NAME, "value":VALUE, "occurrence":OCCURENCE,  "ope":OPERATOR}}
+         * {"rule":{"tracktype":TRACKTYPE, "field":FIELD, "level" LEVEL, "id":RULE_ID, "name":NAME, "value":VALUE, "occurrence":OCCURENCE,  "ope":OPERATOR}}
          */
 
         webpage.xslt_policy_rule_duplicate(policyId, ruleNode.data.ruleId, dstNode.data.policyId, function(res){
@@ -340,7 +353,7 @@ var policyTreeAjax = (function() {
          * @param int dstPolicyId policy ID of the destination policy
          *
          * @return json
-         * {"rule":{"tracktype":TRACKTYPE, "field":FIELD, "id":RULE_ID, "name":NAME, "value":VALUE, "occurrence":OCCURENCE, "ope":OPERATOR}}
+         * {"rule":{"tracktype":TRACKTYPE, "field":FIELD, "level" LEVEL, "id":RULE_ID, "name":NAME, "value":VALUE, "occurrence":OCCURENCE, "ope":OPERATOR}}
          */
 
         webpage.xslt_policy_rule_move(policyId, ruleNode.data.ruleId, dstNode.data.policyId, function(res){
